@@ -12,9 +12,10 @@
 # implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-import base64
-import json
 
+import base64
+
+from oslo_serialization import jsonutils
 from oslo_utils import timeutils
 
 from barbicanclient import base
@@ -26,14 +27,14 @@ from barbicanclient.v1 import secrets
 
 class SecretData(object):
     def __init__(self):
-        self.name = u'Self destruction sequence'
-        self.payload = u'the magic words are squeamish ossifrage'
-        self.payload_content_type = u'text/plain'
-        self.algorithm = u'AES'
+        self.name = 'Self destruction sequence'
+        self.payload = 'the magic words are squeamish ossifrage'
+        self.payload_content_type = 'text/plain'
+        self.algorithm = 'AES'
         self.created = str(timeutils.utcnow())
 
         self.secret_dict = {'name': self.name,
-                            'status': u'ACTIVE',
+                            'status': 'ACTIVE',
                             'algorithm': self.algorithm,
                             'created': self.created}
 
@@ -72,7 +73,7 @@ class WhenTestingSecrets(test_client.BaseEntityResource):
         self.assertEqual(self.entity_href, secret_href)
 
         # Verify that correct information was sent in the call.
-        secret_req = json.loads(self.responses.last_request.text)
+        secret_req = jsonutils.loads(self.responses.last_request.text)
         self.assertEqual(self.secret.name, secret_req['name'])
         self.assertEqual(self.secret.payload, secret_req['payload'])
 
@@ -87,12 +88,12 @@ class WhenTestingSecrets(test_client.BaseEntityResource):
         self.assertEqual(self.entity_href, secret_href)
 
         # Verify that correct information was sent in the call.
-        secret_req = json.loads(self.responses.last_request.text)
+        secret_req = jsonutils.loads(self.responses.last_request.text)
         self.assertEqual(self.secret.name, secret_req['name'])
         self.assertEqual(self.secret.payload, secret_req['payload'])
 
     def test_should_store_binary_type_as_octet_stream(self):
-        """We use six.binary_type as the canonical binary type.
+        """We use bytes as the canonical binary type.
 
         The client should base64 encode the payload before sending the
         request.
@@ -100,8 +101,6 @@ class WhenTestingSecrets(test_client.BaseEntityResource):
         data = {'secret_ref': self.entity_href}
         self.responses.post(self.entity_base + '/', json=data)
 
-        # This literal will have type(str) in Python 2, but will have
-        # type(bytes) in Python 3.  It is six.binary_type in both cases.
         binary_payload = b'F\x130\x89f\x8e\xd9\xa1\x0e\x1f\r\xf67uu\x8b'
 
         secret = self.manager.create()
@@ -109,30 +108,28 @@ class WhenTestingSecrets(test_client.BaseEntityResource):
         secret.payload = binary_payload
         secret.store()
 
-        secret_req = json.loads(self.responses.last_request.text)
+        secret_req = jsonutils.loads(self.responses.last_request.text)
         self.assertEqual(self.secret.name, secret_req['name'])
-        self.assertEqual(u'application/octet-stream',
+        self.assertEqual('application/octet-stream',
                          secret_req['payload_content_type'])
-        self.assertEqual(u'base64',
+        self.assertEqual('base64',
                          secret_req['payload_content_encoding'])
         self.assertNotEqual(binary_payload, secret_req['payload'])
 
     def test_should_store_text_type_as_text_plain(self):
-        """We use six.text_type as the canonical text type."""
+        """We use unicode string as the canonical text type."""
         data = {'secret_ref': self.entity_href}
         self.responses.post(self.entity_base + '/', json=data)
 
-        # This literal will have type(unicode) in Python 2, but will have
-        # type(str) in Python 3.  It is six.text_type in both cases.
-        text_payload = u'time for an ice cold \U0001f37a'
+        text_payload = 'time for an ice cold \U0001f37a'
 
         secret = self.manager.create()
         secret.payload = text_payload
         secret.store()
 
-        secret_req = json.loads(self.responses.last_request.text)
+        secret_req = jsonutils.loads(self.responses.last_request.text)
         self.assertEqual(text_payload, secret_req['payload'])
-        self.assertEqual(u'text/plain', secret_req['payload_content_type'])
+        self.assertEqual('text/plain', secret_req['payload_content_type'])
 
     def test_should_store_with_deprecated_content_type(self):
         """DEPRECATION WARNING
@@ -144,14 +141,14 @@ class WhenTestingSecrets(test_client.BaseEntityResource):
         self.responses.post(self.entity_base + '/', json=data)
 
         payload = 'I should be octet-stream'
-        payload_content_type = u'text/plain'
+        payload_content_type = 'text/plain'
 
         secret = self.manager.create()
         secret.payload = payload
         secret.payload_content_type = payload_content_type
         secret.store()
 
-        secret_req = json.loads(self.responses.last_request.text)
+        secret_req = jsonutils.loads(self.responses.last_request.text)
         self.assertEqual(payload, secret_req['payload'])
         self.assertEqual(payload_content_type,
                          secret_req['payload_content_type'])
@@ -168,8 +165,8 @@ class WhenTestingSecrets(test_client.BaseEntityResource):
         encoded_payload = base64.b64encode(
             b'F\x130\x89f\x8e\xd9\xa1\x0e\x1f\r\xf67uu\x8b'
         ).decode('UTF-8')
-        payload_content_type = u'application/octet-stream'
-        payload_content_encoding = u'base64'
+        payload_content_type = 'application/octet-stream'
+        payload_content_encoding = 'base64'
 
         secret = self.manager.create()
         secret.payload = encoded_payload
@@ -177,7 +174,7 @@ class WhenTestingSecrets(test_client.BaseEntityResource):
         secret.payload_content_encoding = payload_content_encoding
         secret.store()
 
-        secret_req = json.loads(self.responses.last_request.text)
+        secret_req = jsonutils.loads(self.responses.last_request.text)
         self.assertEqual(encoded_payload, secret_req['payload'])
         self.assertEqual(payload_content_type,
                          secret_req['payload_content_type'])
@@ -447,9 +444,7 @@ class WhenTestingSecrets(test_client.BaseEntityResource):
         self.test_should_delete_from_object(self.entity_id)
 
     def test_should_update_from_manager(self, secret_ref=None):
-        # This literal will have type(unicode) in Python 2, but will have
-        # type(str) in Python 3.  It is six.text_type in both cases.
-        text_payload = u'time for an ice cold \U0001f37a'
+        text_payload = 'time for an ice cold \U0001f37a'
         secret_ref = secret_ref or self.entity_href
 
         self.responses.put(self.entity_href, status_code=204)
@@ -478,9 +473,7 @@ class WhenTestingSecrets(test_client.BaseEntityResource):
         # Verify the secret has the correct ref for testing updates
         self.assertEqual(secref_ref, secret.secret_ref)
 
-        # This literal will have type(unicode) in Python 2, but will have
-        # type(str) in Python 3.  It is six.text_type in both cases.
-        text_payload = u'time for an ice cold \U0001f37a'
+        text_payload = 'time for an ice cold \U0001f37a'
 
         self.responses.put(self.entity_href, status_code=204)
 
