@@ -17,7 +17,6 @@ import functools
 import logging
 
 from oslo_utils.timeutils import parse_isotime
-import six
 
 from barbicanclient import base
 from barbicanclient import formatter
@@ -113,8 +112,7 @@ class CertificateOrderFormatter(formatter.EntityFormatter):
         return data
 
 
-@six.add_metaclass(abc.ABCMeta)
-class Order(object):
+class Order(object, metaclass=abc.ABCMeta):
     """Base order object to hold common functionality
 
     This should be considered an abstract class that should not be
@@ -251,8 +249,8 @@ class Order(object):
 class KeyOrder(Order, KeyOrderFormatter):
     """KeyOrders can be used to request random key material from Barbican"""
     _type = 'key'
-    _validMeta = (u'name', u'algorithm', u'mode', u'bit_length', u'expiration',
-                  u'payload_content_type')
+    _validMeta = ('name', 'algorithm', 'mode', 'bit_length', 'expiration',
+                  'payload_content_type')
 
     def __init__(self, api, name=None, algorithm=None, bit_length=None,
                  mode=None, expiration=None, payload_content_type=None,
