@@ -12,20 +12,19 @@
 # implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-import uuid
-
 from testtools import testcase
 
-from functionaltests import utils
 from functionaltests.client import base
 from functionaltests.common import cleanup
+from functionaltests import utils
+from oslo_utils import uuidutils
 
 from barbicanclient import exceptions
 
 
 create_secret_defaults_data = {
     "name": "AES key",
-    "expiration": "2018-02-28T19:14:44.180394",
+    "expiration": "2030-02-28T19:14:44.180394",
     "algorithm": "aes",
     "bit_length": 256,
     "mode": "cbc",
@@ -262,7 +261,7 @@ class ACLsTestCase(BaseACLsTestCase):
         This should return a 404.
         """
         base_url = self.barbicanclient.acls._api.endpoint_override
-        new_uuid = str(uuid.uuid4())
+        new_uuid = uuidutils.generate_uuid()
         url = '{0}/containers/{1}'.format(base_url, new_uuid)
 
         e = self.assertRaises(
@@ -271,7 +270,7 @@ class ACLsTestCase(BaseACLsTestCase):
             url
         )
 
-        self.assertEqual(e.status_code, 404)
+        self.assertEqual(404, e.status_code)
 
     @testcase.attr('negative')
     def test_delete_non_existent_secret_valid_uuid(self):
@@ -280,7 +279,7 @@ class ACLsTestCase(BaseACLsTestCase):
         This should return a 404.
         """
         base_url = self.barbicanclient.acls._api.endpoint_override
-        new_uuid = str(uuid.uuid4())
+        new_uuid = uuidutils.generate_uuid()
         url = '{0}/secrets/{1}'.format(base_url, new_uuid)
 
         acl_data = {'entity_ref': url}
@@ -291,7 +290,7 @@ class ACLsTestCase(BaseACLsTestCase):
             entity.remove
         )
 
-        self.assertEqual(e.status_code, 404)
+        self.assertEqual(404, e.status_code)
 
     @utils.parameterized_dataset(ACL_SUBMIT_DATA_POSITIVE)
     @testcase.attr('positive')
@@ -333,10 +332,7 @@ class ACLsTestCase(BaseACLsTestCase):
     def test_acl_incorrect_submit(self, users, project_access,
                                   entity_ref_method, acl_type, expect_users,
                                   expect_project_access, **kwargs):
-        """Incorrect Submit operation on ACL entity which stores ACL setting in
-        Barbican.
-
-        """
+        """Check incorrect submit operation failure on ACL entity."""
         entity_ref, _ = getattr(self, entity_ref_method)()
 
         acl_data = {'entity_ref': entity_ref, 'users': users,
@@ -349,7 +345,7 @@ class ACLsTestCase(BaseACLsTestCase):
             entity.submit
         )
         if hasattr(e, 'status_code'):
-            self.assertEqual(e.status_code, kwargs.get('error_code'))
+            self.assertEqual(kwargs.get('error_code'), e.status_code)
 
     @utils.parameterized_dataset(ACL_DELETE_DATA)
     def test_acl_delete(self, users, project_access, entity_ref_method,
@@ -476,7 +472,7 @@ class ACLsTestCase(BaseACLsTestCase):
             server_acl.submit
         )
         if hasattr(e, 'status_code'):
-            self.assertEqual(e.status_code, kwargs.get('error_code'))
+            self.assertEqual(kwargs.get('error_code'), e.status_code)
 
     @utils.parameterized_dataset(ACL_REMOVE_USERS_DATA_POSITIVE)
     @testcase.attr('positive')
@@ -503,7 +499,8 @@ class ACLsTestCase(BaseACLsTestCase):
         acl_users = server_acl.read.users
         if acl_users and remove_users:
             acl_users = set(acl_users).difference(remove_users)
-            server_acl.read.users = acl_users
+            # Python sets are not JSON serializable. Cast acl_users to a list.
+            server_acl.read.users = list(acl_users)
 
         if kwargs.get('remove_project_access') is not None:
             server_acl.read.project_access = \
@@ -554,7 +551,8 @@ class ACLsTestCase(BaseACLsTestCase):
         acl_users = server_acl.read.users
         if acl_users and remove_users:
             acl_users = set(acl_users).difference(remove_users)
-            server_acl.read.users = acl_users
+            # Python sets are not JSON serializable. Cast acl_users to a list.
+            server_acl.read.users = list(acl_users)
 
         if kwargs.get('remove_project_access') is not None:
             server_acl.read.project_access = \
@@ -566,4 +564,4 @@ class ACLsTestCase(BaseACLsTestCase):
             server_acl.submit
         )
         if hasattr(e, 'status_code'):
-            self.assertEqual(e.status_code, kwargs.get('error_code'))
+            self.assertEqual(kwargs.get('error_code'), e.status_code)
